package SPVM::Net::SSLeay::SSL_METHOD;



1;

=head1 Name

SPVM::Net::SSLeay::SSL_METHOD - SSL/TLS Methods

=head1 Description

The Net::SSLeay::SSL_METHOD class of L<SPVM> has methods for SSL/TLS methods.

=head1 Usage

  use Net::SSLeay::SSL_METHOD;

=head1 Class Methods

=head2 SSLv23_client_method

  static method SSLv23_client_method : Net::SSLeay::SSL_METHOD ();

=head2 SSLv23_server_method

  static method SSLv23_server_method : Net::SSLeay::SSL_METHOD ();

=head2 TLS_client_method

  static method TLS_client_method : Net::SSLeay::SSL_METHOD ();

=head2 TLS_server_method

  static method TLS_server_method : Net::SSLeay::SSL_METHOD ();

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

