package SPVM::Net::SSLeay::BIO;



1;

=head1 Name

SPVM::Net::SSLeay::BIO - BIO

=head1 Description

The Net::SSLeay::BIO class of L<SPVM> has methods to manipulate BIO.

=head1 Usage

  use Net::SSLeay::BIO;

=head1 Class Methods

 static method new : Net::SSLeay::BIO ();

=head1 Instance Methods

 method DESTROY : void ();

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

